@@ -19,8 +19,8 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GUPNP_ERROR_H__
-#define __GUPNP_ERROR_H__
+#ifndef GUPNP_ERROR_H
+#define GUPNP_ERROR_H
 
 #include <glib.h>
 
@@ -118,6 +118,28 @@ typedef enum {
         GUPNP_XML_ERROR_OTHER
 } GUPnPXMLError;
 
+GQuark
+gupnp_rootdevice_error_quark (void) G_GNUC_CONST;
+
+#define GUPNP_ROOT_DEVICE_ERROR (gupnp_rootdevice_error_quark ())
+
+/**
+ * GUPnPRootDeviceError:
+ * @GUPNP_ROOT_DEVICE_ERROR_NO_CONTEXT: No #GUPnPContext was passed to the root device.
+ * @GUPNP_ROOT_DEVICE_ERROR_NO_DESCRIPTION_PATH: Device description path was missing
+ * @GUPNP_ROOT_DEVICE_ERROR_NO_DESCRIPTION_FOLDER: Description folder was missing
+ * @GUPNP_ROOT_DEVICE_ERROR_NO_NETWORK: Network interface is not usable
+ *
+ * #GError codes used for errors during #GUPnPRootDevice creation
+ */
+typedef enum {
+        GUPNP_ROOT_DEVICE_ERROR_NO_CONTEXT,
+        GUPNP_ROOT_DEVICE_ERROR_NO_DESCRIPTION_PATH,
+        GUPNP_ROOT_DEVICE_ERROR_NO_DESCRIPTION_FOLDER,
+        GUPNP_ROOT_DEVICE_ERROR_NO_NETWORK,
+        GUPNP_ROOT_DEVICE_ERROR_FAIL
+} GUPnPRootdeviceError;
+
 G_END_DECLS
 
-#endif /* __GUPNP_ERROR_H__ */
+#endif /* GUPNP_ERROR_H */
